`suddendeath` is a package to generate "突然の死" like message

Setup
-----

::

  $ easy_install suddendeath


Run
---

With default, it generates "突然の死"::

  % suddendeath
  ＿人人人人人人＿
  ＞　突然の死　＜
  ￣Y^Y^Y^Y^Y￣

You can provide arbitrary message to the `suddendeath` command::

  % suddendeath 突然のNullPointerException
  ＿人人人人人人人人人人人人人人人＿
  ＞　突然のNullPointerException　＜
  ￣Y^Y^Y^Y^Y^Y^Y^Y^Y^Y^Y^Y^Y^Y￣
